@@ -4,11 +4,13 @@ import requests
 from .auth import Authenticator
 from .v3.aws_integration import AwsIntegration
 from .v3.cert_auth import CertAuth
+from .v3.device_tests import DeviceTests
 from .v3.devices import Devices
 from .v3.dialects import Dialects
 from .v3.domains import Domains
 from .v3.data_model import DataModel
 from .v3.device_monitoring import DeviceMonitoring
+from .v3.extensions import Extensions
 from .v3.lifecycle_management import LifecycleManagement
 from .v3.resources import Resources
 from .v3.sessions import Sessions
@@ -46,9 +48,11 @@ class Coiote:
         self.cert_auth: CertAuth = self._make_module(CertAuth)
         self.data_model: DataModel = self._make_module(DataModel)
         self.device_monitoring: DeviceMonitoring = self._make_module(DeviceMonitoring)
+        self.device_tests: DeviceTests = self._make_module(DeviceTests)
         self.devices: Devices = self._make_module(Devices)
         self.dialects: Dialects = self._make_module(Dialects)
         self.domains: Domains = self._make_module(Domains)
+        self.extensions: Extensions = self._make_module(Extensions)
         self.lifecycle_management: LifecycleManagement = self._make_module(LifecycleManagement)
         self.resources: Resources = self._make_module(Resources)
         self.sessions: Sessions = self._make_module(Sessions)
